# -*- coding: utf-8 -*-


import datetime
import os.path
import sys

from shutil import which

import bignole


HEADER = (
    """
# THIS FILE WAS AUTOGENERATED BY bignole on {date}.
# IT MAKES NO SENSE TO EDIT IT MANUALLY!
#
# BIGNOLERC FILE: {rc_file}
#
# PLEASE VISIT https://framagit.org/fiat-tux/bignole FOR DETAILS.
""".strip()
    + "\n\n"
)


SYSTEMD_CONFIG = """
[Unit]
Description=Daemon for converting ~/.bignolerc to ~/.ssh/config

[Service]
ExecStart={command} -u {templater} -o {sshconfig}
Restart=on-failure

[Install]
WantedBy=default.target
""".strip()

SYSTEMD_SERVICE_NAME = "bignole.service"

SYSTEMD_INSTRUCTIONS = """
Please execute following lines or compose script:

$ mkdir -p "{systemd_user_path}" || true
$ cat > "{systemd_user_service_path}" <<EOF
{systemd_config}
EOF
$ systemctl --user enable {service_name}
$ systemctl --user start {service_name}
""".strip()


def make_header(**kwargs):
    """Create the SSH config header with the generation date and time"""
    return HEADER.format(
        date=kwargs.get("date", datetime.datetime.now().ctime()),
        rc_file=kwargs.get("rc_file", "???"),
    )


def make_systemd_script(templater):
    """Output systemd script and instructions"""
    if templater is None:
        templater = "dummy"
    systemd_user_path = os.path.join(bignole.HOME_DIR, ".config", "systemd", "user")
    systemd_user_service_path = os.path.join(systemd_user_path, SYSTEMD_SERVICE_NAME)
    systemd_config = SYSTEMD_CONFIG.format(
        command=which(sys.argv[0]),
        sshconfig=bignole.DEFAULT_SSHCONFIG,
        templater=templater,
    )

    yield f'mkdir -p "{systemd_user_path}" || true'
    yield f'cat > "{systemd_user_service_path}" <<EOF\n{systemd_config.strip()}\nEOF'
    yield f"systemctl --user enable {SYSTEMD_SERVICE_NAME}"
    yield f"systemctl --user start {SYSTEMD_SERVICE_NAME}"
